Bootstrap Switch · Turn checkboxes and radio buttons in toggle switches
Author: Mattia Larentis, Emanuele Marchi and Peter Stein
Description: Turn checkboxes and radio buttons in toggle switches.

## Bootstrap Switch 3 2.0.1

Turn checkboxes and radio buttons in toggle switches.

Select the version to download:

Download 3 Download 2.0.1

Documentation in progress!
It might not seem, but it's actually a lot of work. The goal is to make it as cleanest, most readable and understandable as possible.
If you feel there is something missing, submit a pull request with your changes. Every help is needed. Many thanks.

# What's new in version 3

- API redesign for a more intuitive use
- Entire code source rewriting focused on cleanliness and performance
- Initialization options can be passed as JavaScript object or written as `data-*`
- Plugin constructor publicly available from `$.fn.bootstrapSwitch.Constructor`
- Plugin instance publicly available calling `.data('bootstrap-switch')`
- Global overridable defaults options
- Improved flexibility with `baseClass` and `wrapperClass` options
- New `onInit` event
- Event namespacing
- Full Bootstrap 3 support
- A lot of fixed bug, as usual

# Getting Started

Include the dependencies: jQuery, Bootstrap and Bootstrap Switch CSS + Javascript.

    [...]
    <link href="bootstrap.css" rel="stylesheet">
    <link href="bootstrap-switch.css" rel="stylesheet">
    <script src="jquery.js"></script>
    <script src="bootstrap-switch.js"></script>
    [...]

Add your checkbox.

    <input type="checkbox" name="my-checkbox" checked>

Initialize Bootstrap Switch.

    $("[name='my-checkbox']").bootstrapSwitch();

Enjoy.

Licensed under the Apache License, Version 2.0 · Created by Mattia Larentis · Mantained by Emanuele Marchi